@@ -122,8 +122,8 @@ available_managers_and_dummy_package = pytest.mark.parametrize(
     (param(m, PACKAGE_IDS[mid], id=mid) for mid, m in pool.items() if m.available),
 )
 
-
-@pytest.hookimpl(hookwrapper=True)
+# XXX Deactive hack while we investigate.
+# @pytest.hookimpl(hookwrapper=True)
 def pytest_runtest_teardown(item, nextitem):
     """Force the reset, after each subcommand test, of NPM's cached CLI path.
 
